from distutils.core import setup

setup(
    name = 'ERPTest',
    packages = [],
    version = '0.1',  # Ideally should be same as your GitHub release tag varsion
    description = 'description',
    author = 'erfan.ghanbari',
    author_email = 'erfan.ghanbari@topnorthamerica.com',
    url = 'https://github.com/erfan-ghanbari/ERPTest.git',
    download_url = 'https://github.com/erfan-ghanbari/ERPTest/archive/refs/tags/erp.tar.gz',
    keywords = ['tag1', 'tag2'],
    classifiers = [],
)
